@@ -1,11 +1,8 @@
 # coding:utf-8
 
-from .util import __version__
-from .util import chdir
-from .util import singleton
-
-from .actuator import Namespace
+from .actuator import cmds
 from .actuator import commands
+from .actuator import Namespace
 from .actuator import add_command
 from .actuator import end_command
 from .actuator import pre_command
@@ -13,4 +10,12 @@ from .actuator import run_command
 
 from .parser import argp
 
+from .colorful import color
+from .colorful import Style
+from .colorful import Fore
+from .colorful import Back
+from .safefile import safile
 from .scanner import scanner
+
+from .util import chdir
+from .util import singleton
